==> threeagent-0.0.1-20190115.032724-1.jar: public/js/out/threeagent/alpha/core.js <==
// Compiled by ClojureScript 1.10.439 {}
goog.provide('threeagent.alpha.core');
goog.require('cljs.core');
goog.require('threeagent.impl.scene');
goog.require('reagent.core');
threeagent.alpha.core.atom = (function threeagent$alpha$core$atom(d){
return reagent.core.atom.call(null,d);
});
threeagent.alpha.core.cursor = (function threeagent$alpha$core$cursor(a,p){
return reagent.core.cursor.call(null,a,p);
});
threeagent.alpha.core.reload_scene = (function threeagent$alpha$core$reload_scene(var_args){
var G__23836 = arguments.length;
switch (G__23836) {
case 2:
return threeagent.alpha.core.reload_scene.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return threeagent.alpha.core.reload_scene.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

threeagent.alpha.core.reload_scene.cljs$core$IFn$_invoke$arity$2 = (function (scene,root_fn){
return threeagent.alpha.core.reload_scene.call(null,scene,root_fn,cljs.core.PersistentArrayMap.EMPTY);
});

threeagent.alpha.core.reload_scene.cljs$core$IFn$_invoke$arity$3 = (function (scene,root_fn,opts){
return threeagent.impl.scene.reset_scene_BANG_.call(null,scene,root_fn,opts);
});

threeagent.alpha.core.reload_scene.cljs$lang$maxFixedArity = 3;

threeagent.alpha.core.render = (function threeagent$alpha$core$render(var_args){
var G__23839 = arguments.length;
switch (G__23839) {
case 2:
return threeagent.alpha.core.render.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return threeagent.alpha.core.render.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

threeagent.alpha.core.render.cljs$core$IFn$_invoke$arity$2 = (function (root_fn,dom_root){
return threeagent.alpha.core.render.call(null,root_fn,dom_root,cljs.core.PersistentArrayMap.EMPTY);
});

threeagent.alpha.core.render.cljs$core$IFn$_invoke$arity$3 = (function (root_fn,dom_root,opts){
return threeagent.impl.scene.render.call(null,root_fn,dom_root,opts);
});

threeagent.alpha.core.render.cljs$lang$maxFixedArity = 3;


//# sourceMappingURL=core.js.map?rel=1547522515314

==> threeagent-0.0.1-20190127.020956-3.jar: public/js/out/threeagent/alpha/core.js <==
// Compiled by ClojureScript 1.10.439 {}
goog.provide('threeagent.alpha.core');
goog.require('cljs.core');
goog.require('threeagent.impl.scene');
goog.require('reagent.ratom');
threeagent.alpha.core.atom = (function threeagent$alpha$core$atom(d){
return reagent.ratom.atom.call(null,d);
});
threeagent.alpha.core.cursor = (function threeagent$alpha$core$cursor(a,p){
return reagent.ratom.cursor.call(null,a,p);
});
threeagent.alpha.core.reload_scene = (function threeagent$alpha$core$reload_scene(var_args){
var G__22234 = arguments.length;
switch (G__22234) {
case 2:
return threeagent.alpha.core.reload_scene.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return threeagent.alpha.core.reload_scene.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

threeagent.alpha.core.reload_scene.cljs$core$IFn$_invoke$arity$2 = (function (scene,root_fn){
return threeagent.alpha.core.reload_scene.call(null,scene,root_fn,cljs.core.PersistentArrayMap.EMPTY);
});

threeagent.alpha.core.reload_scene.cljs$core$IFn$_invoke$arity$3 = (function (scene,root_fn,opts){
return threeagent.impl.scene.reset_scene_BANG_.call(null,scene,root_fn,opts);
});

threeagent.alpha.core.reload_scene.cljs$lang$maxFixedArity = 3;

threeagent.alpha.core.render = (function threeagent$alpha$core$render(var_args){
var G__22237 = arguments.length;
switch (G__22237) {
case 2:
return threeagent.alpha.core.render.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return threeagent.alpha.core.render.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

threeagent.alpha.core.render.cljs$core$IFn$_invoke$arity$2 = (function (root_fn,dom_root){
return threeagent.alpha.core.render.call(null,root_fn,dom_root,cljs.core.PersistentArrayMap.EMPTY);
});

threeagent.alpha.core.render.cljs$core$IFn$_invoke$arity$3 = (function (root_fn,dom_root,opts){
return threeagent.impl.scene.render.call(null,root_fn,dom_root,opts);
});

threeagent.alpha.core.render.cljs$lang$maxFixedArity = 3;


//# sourceMappingURL=core.js.map?rel=1548301234864
